@@ -1,3 +1,5 @@
+from urllib.parse import urlparse
+
 import dvc.output as output
 from dvc.dependency.gs import DependencyGS
 from dvc.dependency.hdfs import DependencyHDFS
@@ -44,8 +46,6 @@ SCHEMA[DependencyREPO.PARAM_REPO] = DependencyREPO.REPO_SCHEMA
 
 
 def _get(stage, p, info):
-    from dvc.utils.compat import urlparse
-
     parsed = urlparse(p)
 
     if parsed.scheme == "remote":
